QuantLET big data reactives Support for reactive use cases that must rely on very large data: infinite reactive graphs (infinite spreadsheets) associated to non-structured repositories. Reactives are organized in distributed nodes, allowing for automatic persistence and in-memory allocation beyond the limits of one single computer.